@@ -1,16 +1,12 @@
 "conjugate.gradient" <-
-function (b, multAx, start = NULL, tol = 1e-05, kmax = 25, verbose = TRUE, 
+function (b, multAx, start, tol = 1e-05, kmax = 25, verbose = TRUE, 
     ...) 
 {
     call <- match.call()
-    if (is.null(start)) {
-        x <- rep(0, length(y))
-        r <- b
-    }
-    else {
+
         x <- start
         r <- b - multAx(x, ...)
-    }
+
     p <- r
     rho <- rep(NA, kmax + 1)
     rho[1 + (0)] <- sum(r^2)
