@@ -1,4 +1,4 @@
-"exp.earth.cov" <-
+"Exp.earth.cov" <-
 function (x1, x2, theta = 1) 
 {
     exp(-rdist.earth(x1, x2)/theta)
