@@ -1,4 +1,4 @@
-"exp.image.cov" <-
+"Exp.image.cov" <-
 function (ind1, ind2, Y, cov.obj = NULL, setup = FALSE, grid, ...) 
 {
     if (is.null(cov.obj)) {
@@ -11,7 +11,7 @@ function (ind1, ind2, Y, cov.obj = NULL, setup = FALSE, grid, ...)
         xg <- make.surface.grid(list((1:M) * dx, (1:N) * dy))
         center <- matrix(c((dx * M)/2, (dy * N)/2), nrow = 1, 
             ncol = 2)
-        out <- exp.cov(xg, center, ...)
+        out <- Exp.cov(xg, center, ...)
         out <- as.surface(xg, c(out))$z
         temp <- matrix(0, nrow = M, ncol = N)
         temp[M/2, N/2] <- 1
