@@ -6,10 +6,17 @@ function (x, ...)
     c2 <- x$num.observation
     c1 <- c(c1, "Number of unique points:")
     c2 <- c(c2, x$num.uniq)
+#
+# print out null space poly info only if "m" is used
+    
+    if( !is.null( x$args.null$m) ) {
     c1 <- c(c1, "Degree of polynomial null space ( base model):")
-    c2 <- c(c2, x$m - 1)
+    c2 <- c(c2, x$m - 1) }
+    
     c1 <- c(c1, "Number of parameters in the null space")
     c2 <- c(c2, x$nt)
+    c1<- c( c1, "Parameters for fixed spatial drift")
+    c2<- c( c2, x$df.drift)
     c1 <- c(c1, "Effective degrees of freedom:")
     c2 <- c(c2, format(round(x$enp, 1)))
     c1 <- c(c1, "Residual degrees of freedom:")
@@ -49,7 +56,7 @@ function (x, ...)
          cat( "  Covariance function is ", x$args$Covariance, fill=TRUE)}
 
     if( !is.null(x$args)){ 
-         cat("  Names of non-defaults covariance arguments: ", fill=TRUE)
+         cat("  Names of non-default covariance arguments: ", fill=TRUE)
          cat("      ",   
                paste( as.character(names( x$args)), collapse=", "),
                   fill=TRUE)}
@@ -72,6 +79,9 @@ function (x, ...)
 
     if( !is.na( x$lambda.est[1])){
           print(x$lambda.est, digits = x$digits)}
+      else{
+        cat( x$lambda, " supplied by user", fill=TRUE)}
+
 
     invisible(x)
 }
