@@ -1,6 +1,7 @@
 "summary.krig.image" <-
-function (x, digits = 4, ...) 
+function (object, digits = 4, ...) 
 {
+    x<- object # S3 hack
     summary <- list(call = x$call, num.observation = length(x$residuals), 
         enp = x$trace, nt = x$nt, res.quantile = quantile(x$residuals, 
             seq(0, 1, 0.25)), shat.MLE = x$shat.MLE, shat.GCV = x$shat.GCV, 
